@@ -1,3 +1,5 @@
+"""Model summary: This is the model summary
+"""
 from kolibri_report.report import Report
 from kolibri.model_trainer import ModelTrainer,ModelConfig
 from kolibri.model_loader import ModelLoader
@@ -21,11 +23,23 @@ y = data.Positive.values.tolist()
 
 trainer = ModelTrainer(ModelConfig(confg))
 
-trainer.fit(X, y)
+# I need to check if the train file is present in that location [model_direc]
+    # not present train the model and not present train the model
+# option 2
+# operator overiding
+while 1:
+    trainer.fit(X, y)
+    train = False
+    model_directory = trainer.persist(confg['output-folder'], fixed_model_name="Cache Test")
+else:
+    model_directory = '/Users/aneruthmohanasundaram/Documents/koli_report_test/Cache Test'
 
-model_directory = trainer.persist(confg['output-folder'], fixed_model_name="Streamlit test")
-# print(model_directory)
-model_interpreter = ModelLoader.load(os.path.join(confg['output-folder'], 'Streamlit test'))
+model_interpreter = ModelLoader.load(os.path.join(confg['output-folder'], 'Cache Test'))
 
 app_report = Report(data,model_interpreter,model_directory)
-app_report.run()
\ No newline at end of file
+app_report.run()
+
+# if __name__ == "__main__":
+#     import sys
+#     # sys.argv
+#     pass
\ No newline at end of file
